@@ -1,22 +1,27 @@
-"""
-WS Server.
+"""ROS 2 BRIDGE.
 
-start_ioloop:
-    Start IO Loop.
-shutdown_ioloop:
-    Stop IO Loop.
-bridge:
-    Complete ROS websocket bridge.
+This is the main function responsible for creating a bridge between
+ROS 2 DDS and Websocket.
+
+Methods:
+    start_ioloop() -> None:
+        Start the io loop.
+
+    shutdown_ioloop(server: HTTPServer) -> None:
+        Stop the io loop.
+
+    bridge(args: Namespace) -> None:
+        Start ROS WS bridge.
 """
 
 import signal
-from typing import Any
+from argparse import Namespace
 
 import rclpy
-from rclpy.node import Node
 
-from .server.ws_server import WebSocketServer
-from .utils.settings import get_ip, get_tornado_settings
+from ros2bridge.ros.bridge_node import RosWSBridge
+from ros2bridge.server.ws_server import WebSocketServer
+from ros2bridge.utils.settings import get_ip, get_tornado_settings
 
 from tornado.httpserver import HTTPServer
 from tornado.ioloop import IOLoop, PeriodicCallback
@@ -25,12 +30,12 @@ from tornado.web import Application
 
 
 def start_ioloop() -> None:
-    """Start the loop."""
+    """Start the io loop."""
     IOLoop.instance().start()
 
 
 def shutdown_ioloop(server: HTTPServer) -> None:
-    """Stop the server loop.
+    """Stop the io loop.
 
     Args:
         server (HTTPServer): Server.
@@ -39,6 +44,7 @@ def shutdown_ioloop(server: HTTPServer) -> None:
 
     def stop_handler(*_) -> None:
         """Stop different signals."""
+
         def shutdown() -> None:
             """Stop the individual signals."""
             server.stop()
@@ -54,15 +60,15 @@ def shutdown_ioloop(server: HTTPServer) -> None:
     signal.signal(signal.SIGINT, stop_handler)
 
 
-def bridge(args: Any = None) -> None:
+def bridge(args: Namespace) -> None:
     """Start ROS WS bridge.
 
     Args:
-        args (Any, optional): _description_. Defaults to None.
+        args (Namespace): Argument from argparse.
     """
-    rclpy.init(args=args)
+    rclpy.init()
 
-    RosWSBridge = Node('ros_bridge_ws')
+    ros_ws_bridge = RosWSBridge()
 
     endpoints = [(r'/', WebSocketServer)]
 
@@ -70,32 +76,30 @@ def bridge(args: Any = None) -> None:
         endpoints,  # type: ignore [arg-type]
         **get_tornado_settings()  # type: ignore [arg-type]
     )
-    url = get_ip()
+
+    url = get_ip(port=str(args.port), ngrok=bool(args.ngrok))
 
     sockets = bind_sockets(**url)  # type: ignore [arg-type]
     server = HTTPServer(ws_app)
     server.add_sockets(sockets)
 
-    try:
-        ros_node = PeriodicCallback(
-            lambda: rclpy.spin_once(  # type: ignore [no-any-return]
-                RosWSBridge, timeout_sec=0.01
-            ),
-            1
-        )
-
-    except KeyboardInterrupt:
-        print('Terminating WS')
+    ros_node = PeriodicCallback(
+        lambda: rclpy.spin_once(  # type: ignore [no-any-return]
+            ros_ws_bridge, timeout_sec=0.01
+        ),
+        1
+    )
 
     shutdown_ioloop(server)
 
     try:
-        print(f"Websocket started: 'ws://{url['address']}:{url['port']}'")
+        print(
+            f"Websocket started: 'ws://{url['address']}:{url['port']}'")
         ros_node.start()
         start_ioloop()
     except KeyboardInterrupt:
         print('Terminating WS')
 
-    RosWSBridge.destroy_node()
+    ros_ws_bridge.destroy_node()
     rclpy.shutdown()
     ros_node.stop()
